@@ -30,6 +30,9 @@ import os.path
 import gobject
 import sys, os, time
 from stat import *
+import time
+from datetime import date
+
 
 class account():
 
@@ -205,6 +208,9 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                  formatted_tweet = self.format_tweet(x.user.screen_name, text, x.created_at, source, reply_to)
+                 #secsSinceEpoc = x.GetCreatedAtInSeconds()
+                 #msgDate = date.fromtimestamp(secsSinceEpoc)
+                 #print msgDate.ctime()
                  self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
