@@ -436,18 +436,8 @@ class WitterUI():
         TwitPic.show()
         menu.append(TwitPic)
 
-        Properties2 = hildon.ColorButton()
-        Properties2.set_label("BgColour_top")
-        # Attach callback to clicked signal
-        Properties2.connect("clicked", self.top_colour_changed)
-        Properties2.show()
-        menu.append(Properties2)
-        Properties3 = hildon.ColorButton()
-        Properties3.set_label("BgColour_bottom")
-        # Attach callback to clicked signal
-        Properties3.connect("clicked", self.bottom_colour_changed)
-        Properties3.show()
-        menu.append(Properties3)
+
+
         Properties = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
         Properties.set_label("Preferences")
         # Attach callback to clicked signal
@@ -758,11 +748,13 @@ class WitterUI():
         print "building stacked menu"
         win = hildon.StackableWindow()
         win.set_title("tweet")
+        pannedArea = hildon.PannableArea()
         vbox1 = gtk.VBox()
         hboxTweet = gtk.HBox()
         hbox0 = gtk.HBox()
         hbox1 = gtk.HBox()
         hbox2 = gtk.HBox()
+        hbox3 = gtk.HBox()
         #empty the dynamic buttons
 
         #add avatar image and the tweet selected
@@ -819,6 +811,8 @@ class WitterUI():
                     label.set_text(select1.get_value(select1.get_iter(item), 10))
                     label.set_use_markup(True)
                     label.set_line_wrap(True)
+                    label.set_selectable(True)
+                    label.select_region(0, 1)
                     hboxTweet.pack_start(label, expand=True)
 
                     id = select1.get_value(select1.get_iter(item), 4)
@@ -898,7 +892,18 @@ class WitterUI():
                 histButton.connect("clicked", self.controller.showHist, name)
                 hbox2.pack_start(histButton, expand=True)
 
-                self.builder.get_object("AtUser").set_label(name)
+                atuser = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                atuser.set_title(name)
+                atuser.connect("clicked", self.controller.tweetAt, name)
+                hbox2.pack_start(atuser, expand=True)
+
+                translate = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                translate.set_title("Translate")
+                translate.connect("clicked", self.controller.Translate, entry)
+                hbox3.pack_start(translate, expand=True)
+
 
                 self.controller.reply_to = id
                 self.controller.reply_to_name = name
@@ -914,7 +919,9 @@ class WitterUI():
         vbox1.pack_start(hbox0, expand=False)
         vbox1.pack_start(hbox1, expand=False)
         vbox1.pack_start(hbox2, expand=False)
-        win.add(vbox1)
+        vbox1.pack_start(hbox3, expand=False)
+        pannedArea.add_with_viewport(vbox1)
+        win.add(pannedArea)
         win.show_all()
 
 
